# Animations

Use Rapporto for animating time series information acquired from different sources.

```{toctree}
:maxdepth: 1
:hidden:

git
```

::::{grid} 3
:gutter: 4

:::{grid-item-card} Git
:link: git
:link-type: doc
:class-card: sd-fs-2
:class-body: sd-text-center
:class-footer: sd-fs-6
{fab}`git;sd-text-grey fa-2xl`
+++
Video of VCS repository commit history.
:::

::::
